@@ -71,9 +71,11 @@ def fetch_apa_data(name, version, target_column, return_X_y=False, as_frame=True
     return b
 
 
-def fetch_dataset(fname):
-    return pd.read_csv(f"{DATALINK}/{fname}.csv", na_values="", sep=",", header=0)
-
+def fetch_dataset(fname, compressed=False):
+    if compressed:
+        return pd.read_csv(f"{DATALINK}/{fname}.csv.gz", na_values="", sep=",", header=0)
+    else:
+        return pd.read_csv(f"{DATALINK}/{fname}.csv", na_values="", sep=",", header=0)
 
 def load_credit_scoring():
     return fetch_dataset('credsco')
@@ -105,6 +107,9 @@ def load_BCN_ruido():
 def load_titanic():
     return fetch_dataset('titanic')
 
+def load_king_county_houses():
+    return fetch_dataset('kc_house_data', compressed=True)
+
 def load_crabs():
     return fetch_dataset('crabs').drop(columns='index')
 
